# AbstractMemory Documentation

AbstractMemory is a small, dependency-light Python library that provides **append-only, temporal, provenance-aware triple assertions** plus **deterministic structured queries**, with optional **vector/semantic retrieval**.

## Start here
- Getting started: [`getting-started.md`](getting-started.md)
- FAQ: [`faq.md`](faq.md)
- Architecture: [`architecture.md`](architecture.md)
- Stores/backends: [`stores.md`](stores.md)
- API reference: [`api.md`](api.md)
- Development: [`development.md`](development.md)
- Backlog: [`backlog/overview.md`](backlog/overview.md)

## Related
- Package overview: [`README.md`](../README.md)
- AbstractFramework ecosystem context: [`architecture.md`](architecture.md)
- Changelog: [`CHANGELOG.md`](../CHANGELOG.md)
- Contributing: [`CONTRIBUTING.md`](../CONTRIBUTING.md)
- Security: [`SECURITY.md`](../SECURITY.md)
- License: [`LICENSE`](../LICENSE)
- Acknowledgments: [`ACKNOWLEDGMENTS.md`](../ACKNOWLEDGMENTS.md)
